RCS annotation element definition (sarpy.annotation.rcs)
========================================================

.. automodule:: sarpy.annotation.rcs
    :members:
    :show-inheritance:
    :inherited-members:
